Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(841)

Unified Diff: third_party/WebKit/Source/modules/accessibility/AXRadioInput.cpp

Issue 2858493002: Rename AXObject to AXObjectImpl in modules/ and web/ (Closed)
Patch Set: Fixed rebase Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/accessibility/AXRadioInput.cpp
diff --git a/third_party/WebKit/Source/modules/accessibility/AXRadioInput.cpp b/third_party/WebKit/Source/modules/accessibility/AXRadioInput.cpp
index bdf674aec4958daa8e4d22dc1439592f8f786341..bb587743b487b9c5909cbf286e0d754898282149 100644
--- a/third_party/WebKit/Source/modules/accessibility/AXRadioInput.cpp
+++ b/third_party/WebKit/Source/modules/accessibility/AXRadioInput.cpp
@@ -39,7 +39,7 @@ void AXRadioInput::UpdatePosAndSetSize(int position) {
void AXRadioInput::RequestUpdateToNextNode(bool forward) {
HTMLInputElement* next_element =
RadioInputType::NextRadioButtonInGroup(GetElement(), forward);
- AXObject* next_a_xobject = AxObjectCache().Get(next_element);
+ AXObjectImpl* next_a_xobject = AxObjectCache().Get(next_element);
if (!next_a_xobject || !next_a_xobject->IsAXRadioInput())
return;
@@ -85,9 +85,10 @@ bool AXRadioInput::CalculatePosInSet() {
HTMLInputElement* prev_element =
RadioInputType::NextRadioButtonInGroup(GetElement(), false);
if (prev_element) {
- AXObject* object = AxObjectCache().Get(prev_element);
- // If the previous element doesn't have AXObject yet, caculate position from
- // the first element. Otherwise, get position from the previous AXObject.
+ AXObjectImpl* object = AxObjectCache().Get(prev_element);
+ // If the previous element doesn't have AXObjectImpl yet, caculate position
+ // from the first element. Otherwise, get position from the previous
+ // AXObjectImpl.
if (!object || !object->IsAXRadioInput()) {
position = CountFromFirstElement();
} else {

Powered by Google App Engine
This is Rietveld 408576698